#[non_exhaustive]pub struct Response {
pub chunk: Vec<Raw<AnyMessageLikeEvent>>,
pub next_batch: Option<String>,
pub prev_batch: Option<String>,
pub recursion_depth: Option<UInt>,
}client or server only.Expand description
Response type for the get_relating_events_with_rel_type_and_event_type endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.chunk: Vec<Raw<AnyMessageLikeEvent>>The paginated child events which point to the parent.
The events returned will match the rel_type and even_type supplied in the URL
and are ordered topologically, most-recent first.
If no events are related to the parent or the pagination yields no results, an
empty chunk is returned.
next_batch: Option<String>An opaque string representing a pagination token.
If this is None, there are no more results to fetch and the client should stop
paginating.
prev_batch: Option<String>An opaque string representing a pagination token.
If this is None, this is the start of the result set, i.e. this is the first
batch/page.
recursion_depth: Option<UInt>If recurse was set on the request, the depth to which the server recursed.
If recurse was not set, this field must be absent.
Implementations